#!/usr/bin/env python3

# Ancillary wrapper around glib-compile-resources that sets up a
# modified environment in order to use the tools that we just
# built instead of the system ones

import argparse
import os

argparser = argparse.ArgumentParser(description='Compile resources')
argparser.add_argument('--glib-compile-resources', metavar='PATH', help='Path to glib-compile-resources')
argparser.add_argument('--pixdata', metavar='PATH', help='Path to gdk-pixbuf-pixdata')
argparser.add_argument('--loaders', metavar='PATH', help='Path to the loaders.cache file')
argparser.add_argument('--sourcedir', metavar='PATH', help='Path to the source directory')
argparser.add_argument('resource', help='GResource XML file')
argparser.add_argument('output', help='Output file')

group = argparser.add_mutually_exclusive_group()
group.add_argument('--header', help='Generate header file', action='store_true')
group.add_argument('--source', help='Generate source file', action='store_true')

args = argparser.parse_args()

cmd = []

if args.glib_compile_resources:
    cmd += [args.glib_compile_resources]
else:
    cmd += ['glib-compile-resources']

if args.header:
    cmd += ['--generate-header']
else:
    cmd += ['--generate-source']

cmd += ['--sourcedir', args.sourcedir]
cmd += [args.resource]
cmd += ['--target', args.output]

newenv = os.environ.copy()
newenv['GDK_PIXBUF_PIXDATA'] = args.pixdata
newenv['GDK_PIXBUF_MODULE_FILE'] = args.loaders

os.execvpe(cmd[0], cmd, newenv)



#!/usr/bin/env python3

# Ancillary wrapper around gdk-pixbuf-print-mime-types that sets up a
# modified environment in order to use the tools that we just built
# instead of the system ones

import argparse
import os
import subprocess
import sys

argparser = argparse.ArgumentParser(description='Compile resources')
argparser.add_argument('--printer', metavar='PATH', help='Path to gdk-pixbuf-print-mime-types')
argparser.add_argument('--pixdata', metavar='PATH', help='Path to gdk-pixbuf-pixdata')
argparser.add_argument('--loaders', metavar='PATH', help='Path to the loaders.cache file')
argparser.add_argument('--bindir', metavar='PATH', help='Path to the source directory')
argparser.add_argument('input', help='Template file')
argparser.add_argument('output', help='Output file')

args = argparser.parse_args()

newenv = os.environ.copy()
newenv['GDK_PIXBUF_PIXDATA'] = args.pixdata
newenv['GDK_PIXBUF_MODULE_FILE'] = args.loaders
# 'nt': NT-based Windows, see https://docs.python.org/3/library/os.html
if os.name == 'nt':
    gdk_pixbuf_dll_buildpath = os.path.dirname(args.pixdata)
    newenv['PATH'] = gdk_pixbuf_dll_buildpath + os.pathsep + newenv['PATH']

cmd = args.printer

mimetypes_out = subprocess.Popen(cmd, env=newenv, stdout=subprocess.PIPE).communicate()[0]
if not mimetypes_out:
    sys.exit(1)

infile = open(args.input, 'r')
outfile = open(args.output, 'w')

for line in infile:
    line = line.replace('@bindir@', args.bindir)
    line = line.replace('@mimetypes@', mimetypes_out.decode('ascii'))
    outfile.write(line)

infile.close()
outfile.close()

sys.exit(0)



#!/usr/bin/env python3

import sys
import os
import argparse

def write_template(filename, data):
    with open(filename, 'w') as f:
        f.write(data)

def build_template(bindir, binname):
    return "[Test]\nType=session\nExec={}\n".format(os.path.join(bindir, binname))

argparser = argparse.ArgumentParser(description='Generate installed-test data.')
argparser.add_argument('--testbindir', metavar='dir', help='Installed test directory')
argparser.add_argument('--testbin', metavar='name', help='Installed test name')
argparser.add_argument('output', help='Output file')

args = argparser.parse_args()

write_template(args.output, build_template(args.testbindir, args.testbin))
